#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.window import Window
from pycatia.system_interfaces.collection import Collection


class Windows(Collection):

    """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Windows
                | 
                | A collection of all the Window objects currently managed by the
                | application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.windows = com_object

    def arrange(self, i_style):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Arrange(CatArrangeStyle iStyle)
                | 
                |     Arranges all the windows of the collection.
                | 
                |     Parameters:
                | 
                |         iStyle
                |             The arrangement style to take into account to arrange the windows
                |             
                | 
                |     Example:
                |         The following example arranges all the windows in the Windows
                |         collection, according to the catArrangeCascade style.
                | 
                |          CATIA.Windows.Arrange(catArrangeCascade)

        :param CatArrangeStyle i_style:
        :return: None
        """
        return self.windows.Arrange(i_style.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'arrange'
        # # vba_code = """
        # # Public Function arrange(windows)
        # #     Dim iStyle (2)
        # #     windows.Arrange iStyle
        # #     arrange = iStyle
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As Window
                | 
                |     Returns a window using its index or its name from the Windows
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the window to retrieve from the collection
                |             of windows. As a numerics, this index is the rank of the window in the
                |             collection. The index of the first window in the collection is 1, and the index
                |             of the last window is Count. As a string, it is the name you assigned to the
                |             window using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved window 
                |     Example:
                |         This example returns in ThisWindow the third window in the collection,
                |         and in ThatWindow the window named MyWindow.
                | 
                |          Dim ThisWindow As Window
                |          Set ThisWindow = CATIA.Windows.Item(3)
                |          Dim ThatWindow As Window
                |          Set ThatWindow = CATIA.Windows.Item("MyWindow")

        :param CATVariant i_index:
        :return: Window
        """
        return Window(self.windows.Item(i_index))

    def __repr__(self):
        return f'Windows(name="{ self.name }")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25

from pycatia.system_interfaces.any_object import AnyObject


class PageSetup(AnyObject):
    """
    .. note::
        CAA V5 Visual Basic help

            | Represents the page setup.The page setup is the object that stores
            | data which defines how yourdocuments and images are actually printed
            | on paper.This data includes namely the paper size, the orientation,the
            | bottom, top, right, and left margins, the zoom factor, the banner,and
            | the printing quality.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.page_setup = com_object

    @property
    def banner(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Banner
                | o Property Banner() As
                | 
                | Returns or sets the banner text.            The banner text is added
                | to the print and can include variables,            such as the user
                | who prints, the date and time of printing.            Available
                | variables are:            $USER                The user name
                | $HOST                The workstation name                $SCALE
                | The print scale                $TIME                The print time
                | $DATE                The print date                $DAY
                | The print day                $MONTH                The print month
                | $YEAR                The print year            The default banner is:
                | Printed by $USER on $DATE $TIME Example:                    This
                | example sets the banner text to the following:
                | Printed by $USER at scale $SCALE on $MONTH/$DAY/$YEAR
                | for the SetupForMyPrint page setup.
                | SetupForMyPrint.Banner = "Printed by $USER at scale $SCALE on
                | $MONTH/$DAY/$YEAR"


        :return: str
        """
        return self.page_setup.Banner

    @banner.setter
    def banner(self, value):
        self.page_setup.Banner = value

    @property
    def banner_position(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | BannerPosition
                | o Property BannerPosition() As
                | 
                | Returns or sets the banner position. The banner can be
                | located on the top, bottom, left, or right side of the
                | page. catBannerPositionNone removes the banner.
                |
                | Example:
                | This example sets the banner on the
                | top side of the page for the SetupForMyPrint
                | page setup.
                | SetupForMyPrint.BannerPosition = CatBannerPositionTop

        :return: int
        """
        return self.page_setup.BannerPosition

    @banner_position.setter
    def banner_position(self, value):
        self.page_setup.BannerPosition = value

    @property
    def banner_size(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | BannerSize
                | o Property BannerSize() As
                | 
                | Returns or sets Banner Size. Banner size could
                | range from 0.1 mm to 10.0 mm Default value is 2.4 mm
                |
                | Example:
                | This example sets banner size for the
                | SetupForMyPrint page setup.
                | SetupForMyPrint.BannerSize = 1.1


        :return: float
        """
        return self.page_setup.BannerSize

    @banner_size.setter
    def banner_size(self, value):
        self.page_setup.BannerSize = value

    @property
    def bottom(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Bottom
                | o Property Bottom() As
                | 
                | Returns or sets the lower left corner location with respect to the
                | bottom of the sheet of paper.
                | This is the distance of the document or the image to print
                | lower left corner to the paper lower left corner.
                |
                | Example:
                | This example sets the location
                | of the lower left corner of the document
                | or the image to print at 40 mm from the paper lower left corner
                | for the SetupForMyPrint page setup.
                | SetupForMyPrint.Bottom = 40

        :return: float
        """
        return self.page_setup.Bottom

    @bottom.setter
    def bottom(self, value):
        self.page_setup.Bottom = value

    @property
    def bottom_margin(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | BottomMargin
                | o Property BottomMargin() As
                | 
                | Returns or sets the bottom margin. The
                | bottom margin is a strip in which nothing is printed, located
                | at the bottom of the page, which height is expressed in mm.
                |
                | Example:
                | This example sets the
                | bottom margin for the SetupForMyPrint
                | page setup to 10 mm.
                | SetupForMyPrint.BottomMargin = 10

        :return:
        """
        return self.page_setup.BottomMargin

    @bottom_margin.setter
    def bottom_margin(self, value):
        self.page_setup.BottomMargin = value

    @property
    def color(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Color
                | o Property Color() As
                | 
                | Returns or sets the color mode to use when printing.
                |
                | Example:
                | This example sets the
                | color mode to GreyScale for the
                | SetupForMyPrint page setup.
                | SetupForMyPrint.Color = catColorGreyScale


        :return: int
        """
        return self.page_setup.Color

    @color.setter
    def color(self, value):
        self.page_setup.Color = value

    @property
    def dpi(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Dpi
                | o Property Dpi() As
                | 
                | Returns or sets the printing dpi.
                |
                | Example:
                | This example sets the printing dpi for the SetupForMyPrint page setup.
                | SetupForMyPrint.Dpi = 150.


        :return: float
        """
        return self.page_setup.Dpi

    @dpi.setter
    def dpi(self, value):
        self.page_setup.Dpi = value

    @property
    def gamma(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Gamma
                | o Property Gamma() As
                | 
                | Returns or sets Gamma factor for print.
                | Gamma value could range from 0.1 to 5.0
                | Default value is 1.0
                |
                | Example:
                | This example sets Gamma factor for the SetupForMyPrint page setup.
                | SetupForMyPrint.Gamma = 1.2

        :return: float
        """
        return self.page_setup.Gamma

    @gamma.setter
    def gamma(self, value):
        self.page_setup.Gamma = value

    @property
    def left(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Left
                | o Property Left() As
                | 
                | Returns or sets the lower left corner location with respect to the
                | left of the sheet of paper.
                | This is the distance of the document or the image to print
                | lower left corner to the paper lower left corner.
                |
                | Example:
                | This example sets the location of the lower left corner of the
                | document or the image to print at 25 mm from the paper lower left corner
                | for the SetupForMyPrint page setup.
                | SetupForMyPrint.Left = 25

        :return: float
        """
        return self.page_setup.Left

    @left.setter
    def left(self, value):
        self.page_setup.Left = value

    @property
    def left_margin(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | LeftMargin
                | o Property LeftMargin() As
                | 
                | Returns or sets the left margin.
                | The left margin is a strip in which nothing is printed, located
                | at the left of the page, which width is expressed in mm.
                |
                | Example: This example sets the left margin for the SetupForMyPrint
                | page setup to 10 mm.
                | SetupForMyPrint.LeftMargin = 10

        :return: float
        """
        return self.page_setup.LeftMargin

    @left_margin.setter
    def left_margin(self, value):
        self.page_setup.LeftMargin = value

    @property
    def line_cap(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | LineCap
                | o Property LineCap() As
                | 
                | Returns or sets Line cap for print.
                | Refer to
                | Default value is catPrintFlat
                | Example:
                |
                | This example sets Line cap for the SetupForMyPrint page setup.
                | SetupForMyPrint.LineCap = catPrintFlat

        :return: int
        """
        return self.page_setup.LineCap

    @line_cap.setter
    def line_cap(self, value):
        self.page_setup.LineCap = value

    @property
    def line_type_overlapping_check(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | LineTypeOverlappingCheck
                | o Property LineTypeOverlappingCheck() As
                | 
                | Returns or sets text Line type overlap check option for
                | print.
                | Default value is FALSE
                |
                | Example:
                | This example sets Line type overlapping check option
                | for the SetupForMyPrint page setup.
                | SetupForMyPrint.LineTypeOverlappingCheck = True

        :return: bool
        """
        return self.page_setup.LineTypeOverlappingCheck

    @line_type_overlapping_check.setter
    def line_type_overlapping_check(self, value):
        self.page_setup.LineTypeOverlappingCheck = value

    @property
    def line_type_specification(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | LineTypeSpecification
                | o Property LineTypeSpecification() As
                | 
                | Returns or sets Line type specification for print.
                | Refer to
                | Default value is catPrintAbsolute
                |
                | Example:
                | This example sets Line type specification
                | for the SetupForMyPrint page setup.
                | SetupForMyPrint.LineTypeSpecification = catPrintAbsolute


        :return: int enumeration_type
        """
        return self.page_setup.LineTypeSpecification

    @line_type_specification.setter
    def line_type_specification(self, value):
        self.page_setup.LineTypeSpecification = value

    @property
    def line_width_specification(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | LineWidthSpecification
                | o Property LineWidthSpecification() As
                | 
                | Returns or sets Line width specification for print.
                | Refer to
                | Default value is catPrintAbsolute
                |
                | Example:
                | This example sets Line width specification
                | for the SetupForMyPrint page setup.
                | SetupForMyPrint.LineWidthSpecification = catPrintAbsolute

        :return: int enumeration_type
        """
        return self.page_setup.LineWidthSpecification

    @line_width_specification.setter
    def line_width_specification(self, value):
        self.page_setup.LineTypeSpecification = value

    @property
    def logo(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Logo
                | o Property Logo() As
                | 
                | Returns or sets the file containing the logo
                | image.
                | The logo is printed with the banner.
                | Example:
                | This example sets the logo file to the
                | following file:
                | e://users//psr//Images//Logo.tif
                | for the SetupForMyPrint page
                | setup.
                | SetupForMyPrint.Logo = "e://users//psr//Images//Logo.tif"


        :return: str
        """
        return self.page_setup.Logo

    @logo.setter
    def logo(self, value):
        self.page_setup.Logo = value

    @property
    def logo_visibility(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | LogoVisibility
                | o Property LogoVisibility() As
                | 
                | Returns or sets LogoVisibility option for
                | print.
                | Default value is FALSE
                |
                | Example:
                | This example sets LogoVisibility option for the SetupForMyPrint page setup.
                | SetupForMyPrint.LogoVisibility = True


        :return: bool
        """
        return self.page_setup.LogoVisibility

    @logo_visibility.setter
    def logo_visibility(self, value):
        self.page_setup.LogoVisibility = value

    @property
    def maximum_size(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | MaximumSize
                | o Property MaximumSize() As
                | 
                | Returns or sets whether the document or the image should be printed
                | at the maximum size with respect to the page size and margins.
                | True if the document or the image is printed with the maximum
                | size. This overrides the location properties,
                | that is Left and Bottom, and the Zoom property values.
                |
                | Example:
                | This example requests to print the document or the image with
                | the SetupForMyPrint page setup at maximum size.
                | SetupForMyPrint.MaximumSize = True

        :return:
        """
        return self.page_setup.MaximumSize

    @maximum_size.setter
    def maximum_size(self, value):
        self.page_setup.MaximumSize = value

    @property
    def orientation(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Orientation
                | o Property Orientation() As
                |
                | Returns or sets the paper orientation.
                | Example:
                | This example sets the paper orientation for the SetupForMyPrint
                | page setup to catPaperLandscape.
                | SetupForMyPrint.Orientation = catPaperLandscape

        :return: int enumeration_type
        """
        return self.page_setup.Orientation

    @orientation.setter
    def orientation(self, value):
        self.page_setup.Orientation = value

    @property
    def paper_height(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | PaperHeight
                | o Property PaperHeight() As
                | 
                | Returns or sets the paper height.
                |
                | Example:
                | This example sets the
                | page height for the SetupForMyPrint
                | page setup to 297 mm..
                | SetupForMyPrint.PaperHeight = 297

        :return: float
        """
        return self.page_setup.PaperHeight

    @paper_height.setter
    def paper_height(self, value):
        self.page_setup.PaperHeight = value

    @property
    def paper_size(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | PaperSize
                | o Property PaperSize() As
                | 
                | Returns or sets the paper
                | size.
                |
                | Example:
                | This example sets the page size for the SetupForMyPrint
                | page setup to catPaperA4.
                | SetupForMyPrint.PaperSize = catPaperA4

        :return:
        """
        return self.page_setup.PaperSize

    @paper_size.setter
    def paper_size(self, value):
        self.page_setup.PaperSize = value

    @property
    def paper_width(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | PaperWidth
                | o Property PaperWidth() As
                | Returns or sets the
                | paper width.
                |
                | Example: This example sets the page width for the SetupForMyPrint
                | page setup to 210 mm..
                | SetupForMyPrint.PaperWidth = 210

        :return: int
        """
        return self.page_setup.PaperWidth

    @paper_width.setter
    def paper_width(self, value):
        self.page_setup.PaperWidth = value

    @property
    def print_rendering_mode(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | PrintRenderingMode
                | o Property PrintRenderingMode() As
                | 
                | Returns or sets theprinting rendering mode.
                |
                | Example:
                | This example sets the printing rendering mode for the SetupForMyPrint
                | page setup.
                | SetupForMyPrint.PrintRenderingMode = CatPrintRenderingModeDefault

        :return: int enumeration_type
        """
        return self.page_setup.PrintRenderingMode

    @print_rendering_mode.setter
    def print_rendering_mode(self, value):
        self.page_setup.PrintRenderingMode = value

    @property
    def quality(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Quality
                | o Property Quality() As
                | 
                | Returns or sets the printing  quality.
                | Refer to
                |
                | Example:
                | This example sets the printing quality to draft for the
                | SetupForMyPrint page setup.
                |
                | SetupForMyPrint.Quality = catPrintQualityDraft

        :return: int enumeration_type
        """
        return self.page_setup.Quality

    @quality.setter
    def quality(self, value):
        self.page_setup.Quality = value

    @property
    def right_margin(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | RightMargin
                | o Property RightMargin() As
                | 
                | Returns or sets the right margin. The right margin is a strip in which
                | nothing is printed, located at the right of the page, which width is
                | expressed in mm.
                |
                | Example:
                | This example sets the right margin for the SetupForMyPrint page setup
                | to 12 mm.
                | SetupForMyPrint.RightMargin = 12

        :return: int
        """
        return self.page_setup.RightMargin

    @right_margin.setter
    def right_margin(self, value):
        self.page_setup.RightMargin = value

    @property
    def rotation(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Rotation
                | o PropertyRotation()As
                | 
                | Returns or sets the rotation of the document or the image to print.
                | Rotations angles can be 0, 90, 180, and 270 degrees counted clockwise.
                |
                | Example:
                | This example sets the rotation to 90 degrees clockwise for the
                | SetupForMyPrint page setup.
                | SetupForMyPrint.Rotation = catImageRotation90

        :return: int
        """
        return self.page_setup.Rotation

    @rotation.setter
    def rotation(self, value):
        self.page_setup.Rotation = value

    @property
    def scaling_to1(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Scaling1To1
                | o Property Scaling1To1() As
                | 
                | Returns or sets whether the document or the image should be printed with a
                | zoom factor equals to 1 and the image to print lower left corner on the paper
                | lower corner.
                |
                | True if the document or the image is printed with the zoom factor equals to
                | 1 and the image to print lower left corner on the paper lower corner.
                | This overrides the location properties, that is Left and Bottom, and the
                | Zoom property values.
                |
                | Example:
                | This example requests to print the document or the image with the SetupForMyPrint page setup.
                | SetupForMyPrint.Scaling1To1 = True

        :return: bool
        """
        return self.page_setup.Scaling1To1

    @scaling_to1.setter
    def scaling_to1(self, value):
        self.page_setup.Scaling1To1 = value

    @property
    def text_blanking(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | TextBlanking
                | o Property TextBlanking() As
                | 
                | Returns or sets the text blanking option in print Text will
                | be printed in blanking rectangle
                | Default value is FALSE
                |
                | Example:
                | This example sets the text blanking option for the SetupForMyPrint
                | page setup.
                | SetupForMyPrint.TextBlanking = True

        :return: bool
        """
        return self.page_setup.TextBlanking

    @text_blanking.setter
    def text_blanking(self, value):
        self.page_setup.TextBlanking = value

    @property
    def text_scaling(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | TextScaling
                | o Property TextScaling() As
                | 
                | Returns or sets text scaling option for print.
                | Default value is TRUE
                |
                | Example:
                | This example sets text scaling option for the SetupForMyPrint page setup.
                | SetupForMyPrint.TextScaling = True

        :return: bool
        """
        return self.page_setup.TextScaling

    @text_scaling.setter
    def text_scaling(self, value):
        self.page_setup.TextScaling = value

    @property
    def top_margin(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | TopMargin
                | o Property TopMargin() As
                | 
                | Returns or sets the top margin. The top margin is a strip in which
                | nothing is printed, located at the top of the page, which height is expressed in  mm.
                | Example:
                | This example sets the top margin for the SetupForMyPrint page setup to 15 mm.
                | SetupForMyPrint.TopMargin = 15

        :return: float
        """
        return self.page_setup.TopMargin

    @top_margin.setter
    def top_margin(self, value):
        self.page_setup.TopMargin = value

    @property
    def use_3d_accuracy(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Use3DAccuracy
                | o Property Use3DAccuracy()As
                | 
                | Returns or sets Use3DAccuracy option for print.
                | Default value is  FALSE
                |
                | Example:
                | This example sets Use3DAccuracy option for the SetupForMyPrint page setup.
                | SetupForMyPrint.Use3DAccuracy = True

        :return: bool
        """
        return self.page_setup.Use3DAccuracy

    @use_3d_accuracy.setter
    def use_3d_accuracy(self, value):
        self.page_setup.Use3DAccuracy = value

    @property
    def use_image_size(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | UseImageSize
                | o Property UseImageSize() As
                | 
                | Returns or sets the paper size to the image size.
                |
                | Example:
                | This example sets the paper size to image size for the
                | SetupForMyPrint page setup.
                | SetupForMyPrint.UseImageSize = True

        :return: bool
        """
        return self.page_setup.UseImageSize

    @use_image_size.setter
    def use_image_size(self, value):
        self.page_setup.UseImageSize = value

    @property
    def white_vectors_in_black(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | WhiteVectorsInBlack
                | o Property WhiteVectorsInBlack() As
                | 
                | Returns or  sets  the  white  vectors  in  black  option.
                | white vectors will be printed in black if set to True Default value is TRUE
                |
                | Example:
                | This example sets the Print White Vectors In Black option for
                | the SetupForMyPrint page setup.
                | SetupForMyPrint.WhiteVectorsInBlack = True

        :return: bool
        """
        return self.page_setup.WhiteVectorsInBlack

    @white_vectors_in_black.setter
    def white_vectors_in_black(self, value):
        self.page_setup.WhiteVectorsInBlack = value

    @property
    def zoom(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Zoom
                | o Property Zoom() As
                | 
                | Returns or sets the zoom factor to use when printing.
                |
                | Example:
                | This example sets the zoom factor to 1.5 for the SetupForMyPrint page setup.
                | SetupForMyPrint.Zoom = 1.5

        :return: float
        """
        return self.page_setup.Zoom

    @zoom.setter
    def zoom(self, value):
        self.page_setup.Zoom = value

    def __repr__(self):
        return f"PageSetup()"



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-18 10:56:40.651039


from .boundary import Boundary


class Face(Boundary):
    """
        .. note::
            CAA V5 Visual Basic help

                | 2-D boundary.Role:
                | ThisactivateLinkAnchor('Boundary','','Boundary')object may be, for
                | example, the lateral face of cylinder. You will create a Face object
                | using theactivateLinkAnchor('Shapes','GetBoundary','Shapes.GetBoundary
                | '),activateLinkAnchor('HybridShapes','GetBoundary','HybridShapes.GetBo
                | undary'),activateLinkAnchor('Sketches','GetBoundary','Sketches.GetBoun
                | dary')oractivateLinkAnchor('Selection','SelectElement2','Selection.Sel
                | ectElement2')method. Then, you pass it to the operator (such asactivat
                | eLinkAnchor('ShapeFactory','AddNewFaceFillet','ShapeFactory.AddNewFace
                | Fillet')).  The lifetime of a Face object is limited,
                | seeactivateLinkAnchor('Boundary','','Boundary').See also:activateLinkA
                | nchor('PlanarFace','','PlanarFace'),activateLinkAnchor('CylindricalFac
                | e','','CylindricalFace').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.face = com_object     

    def __repr__(self):
        return f'Face(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.in_interfaces.reference import Reference


class Boundary(Reference):
    """
        .. note::
            CAA V5 Visual Basic help

                | Topological cell, such as a face, an edge or a vertex.Role:  The
                | Boundary objects are basic topological objects, such as the edge of a
                | Pad. Some of them posess  a geometrical feature
                | (planarface,rectilinearedge). You will create a Boundary object (such
                | as theactivateLinkAnchor('TriDimFeatEdge','','TriDimFeatEdge')object,
                | which is derived, indirectly,  from the Boundary object) using theacti
                | vateLinkAnchor('Shapes','GetBoundary','Shapes.GetBoundary'),activateLi
                | nkAnchor('HybridShapes','GetBoundary','HybridShapes.GetBoundary'),acti
                | vateLinkAnchor('Sketches','GetBoundary','Sketches.GetBoundary')oractiv
                | ateLinkAnchor('Selection','SelectElement2','Selection.SelectElement2')
                | method. Then, you pass it to the operator (such asactivateLinkAnchor('
                | ShapeFactory','AddNewEdgeFilletWithConstantRadius','ShapeFactory.AddNe
                | wEdgeFilletWithConstantRadius')). Note that, regarding V4 sub-
                | elements, once the data of a CATIA Version 4 Model has been copied to
                | a .CATPart, the sub-elements of the resulting .CATPart are supported
                | by theactivateLinkAnchor('Boundary','','Boundary')object.  The
                | lifetime of a Boundary object is limited. In particular, after having
                | callactivateLinkAnchor('Part','Update','Part.Update'), the Boundary
                | objects are usually no more valid.See
                | also:Note:activateLinkAnchor('Boundary','','Boundary')objects cannot
                | be selected into the specification tree.Note:For
                | aactivateLinkAnchor('Boundary','','Boundary')object, the object
                | returned by
                | theactivateLinkAnchor('AnyObject','Parent','AnyObject.Parent')property
                | is the master shape. For example, if we have:

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.boundary = com_object

    def __repr__(self):
        return f'Boudary()'





#! /usr/bin/python3.6

from pathlib import Path
import warnings

from pywintypes import com_error

from pycatia.exception_handling import CATIAApplicationException
from pycatia.mec_mod_interfaces.part import Part
from pycatia.product_structure_interfaces.product import Product
from pycatia.space_analyses_interfaces.spa_workbench import SPAWorkbench
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.drafting_interfaces.drawing_root import DrawingRoot


class Document(AnyObject):
    """
    The Document object is used to access the currently active document in the catia session.

    If the document fails to activate try closing CATIA and killing any existing COM object
    processes in task manager.

    .. note::

        CAA V5 Visual Basic help

        The Document is the object which stores your pycatia data on disk. A document is either created
        empty using the File->New command or using the Add method of the Documents collection, or opened
        from a file using the File->Open command or using the Open method of the Documents collection.
        CATIA provides access to four document types: the PartDocument, the ProductDocument, the
        DrawingDocument and the AnalysisDocument. The Document abstract object gathers the properties and
        methods common to all actual document types. When a document is created or opened, it is
        automatically set as the active document and displayed in a window which automatically becomes
        the active window. A document aggregates the current object or set of objects in the Selection
        object, and Cameras, a camera collection.

    """

    def __init__(self, document_com_object):
        super().__init__(document_com_object)
        try:
            self.document = document_com_object
            self.catia = document_com_object
        except com_error:
            message = "Could not activate document. Is a document open?"
            raise CATIAApplicationException(message)

    @property
    def is_part(self):
        """
        Determine whether the active document is a CATPart.

        :return: bool
        """
        try:
            if self.part().part:
                return True
        except AttributeError:
            return False

    @property
    def is_product(self):
        """
        Determine whether the active document is a CATProduct.

        :return: bool
        """

        if self.product().is_catproduct():
            return True
        return False

    @property
    def is_saved(self):
        """
        Returns true if document is saved.

        .. note::
            CAA V5 Visual Basic help

            Property Saved( ) As boolean (Read Only)

            Returns whether the document has been modified, and thus needs to be saved.
            This happens when the document has changed since either its creation or its last save.
            True if the document has not been changed: the document doesn't need to be saved.
            False if the document has been changed: the document needs to be saved.

            | Example:
            | This example retrieves in HasChanged whether the Doc document needs to be saved.
            | HasChanged = NOT Doc.Saved

        :return: bool
        """

        return self.document.Saved

    @property
    def full_name(self):
        """

        .. note::
            CAA V5 Visual Basic help

            Property FullName( ) As CATBSTR (Read Only)

            | Returns the document's full file name, including its path.
            | Example:
            | This example retrieves in DocFullName the Doc document's full file name.
            |     DocFullName = Doc.FullName
            |
            | The returned value is like this:
            |     e://users//psr//Parts//MyNicePart.CATPart


        :return: str - full path document name
        """

        return str(self.path())

    def drawing_root(self):
        """
        :return:
        """
        return DrawingRoot(self.document.DrawingRoot)

    def export_data(self, filename, filetype):

        """
        .. note::
            CAA V5 Visual Basic help

            Sub ExportData( CATBSTR  fileName, CATBSTR  format)

            | Exports the data contained in the document to another format.
            | Parameters:
            |   fileName
            |       The name of the exported file
            |   format
            |       The name of the format
            | Example:
            |   This example writes the Doc document in the IGES format under the IGESDoc name.
            |       Doc.ExportData("IGESDoc", "igs")


        :param str filename: filename including full path.
        :param str filetype: filetype is the extension of required filetype. The filetype must be supported by CATIA.
        :return:
        """

        self.document.ExportData(filename, filetype)

    def path(self):
        """

        Returns the pathlib.Path() object of the document fullname.

        example e://users//psr//Parts//MyNicePart.CATPart
        >>> Document.path().name
        MyNicePart.CATPart
        >>> Document.path().parent
        e://users//psr//Parts//
        >>> Document.path().suffix
        .CATPart

        :return: Path()
        """

        return Path(self.document.FullName)

    def part(self):
        """
        :return: Part()
        """

        return Part(self.document.Part)

    def product(self):
        """
        :return: :class:`Product()`
        """

        return Product(self.document.Product)

    def activate(self):
        """
        Activates the document

        .. note::
            CAA V5 Visual Basic help

            Sub Activate( )

            Activates the document. Activating a document means that this document is the one on which the end user is
            now working on. This document possibly reconfigures the menu bar and toolbars with its own commands if its
            type is different from the type of the previous active document. The first window in the window collection
            which contains this document becomes the active one.

            Example:
            | This example activates the Doc document.
            | Doc.Activate()

        """

        self.document.Activate()

    def close(self):
        """
        Closes the current document.

        .. note::
            CAA V5 Visual Basic help

            Sub Close( )

            Closes the document. This closes all the windows displaying the document. If the document needs to be saved,
            the end user is prompted whether to save the document, or to close it anyway.

            | Example:
            | This example closes the Doc document
            |  Doc.Close()

        """
        self.logger.info(f'Closing current active document.'
                         f' CATIA will prompt you to save if you haven\'t already done so.')
        self.document.Close()

    def save(self):
        """
        Save the current document.

        .. note::
            CAA V5 Visual Basic help

            Sub Save( )

            Saves the document.
            | Example:
            | This example saves the Doc document.
            | Doc.Save()

        """
        self.logger.info(f'Saving the current document.')
        self.document.Save()

    def save_as(self, file_name, overwrite=False):
        """
        Save the document to a new name.

        .. note::
            CAA V5 Visual Basic help

            Sub SaveAs( CATBSTR  fileName)

            Saves the document with another name.
            |  Parameters:
            |     fileName
            |         The name to assign to the document
            | Example:
            | This example saves the Doc document with the NewName name.
            | Doc.SaveAs("NewName")

        :param str file_name: full pathname to new file_name
        :param bool overwrite:
        """

        file_name = Path(file_name)
        if overwrite is False:
            if file_name.is_file():
                raise FileExistsError(f'File: {file_name} already exists.')
        else:
            if file_name.is_file():
                warnings.warn('File already exists. Click YES in CATIA V5.')
        self.document.SaveAs(file_name)

    @staticmethod
    def search_for_items(document, selection_objects):
        """

        # todo: This search is currently restricted to GSD objects only.

        Selection objects is a list of items to search for.
        Example: selection_objects = ['Point', 'Line']

        Example query string to search for all lines and points
        "('Generative Shape Design'.Point + 'Generative Shape Design'.Line),in"

        :param document:
        :param list selection_objects:
        :return Selected Automation Object:
        """

        gsd_items = [
            'Point',
            'Line'
        ]

        query_string = str()
        # build query string

        for counter, item in enumerate(selection_objects):
            boolean = str()
            if counter > 0 and not counter == len(selection_objects):
                boolean = ' + '
            if item in gsd_items:
                query_string = f"{query_string}{boolean}'Generative Shape Design'.{item}"

        query_string = f"({query_string}),in"

        selection = document.document.Selection
        selection.Search(query_string)

        selected = list()
        for i in range(0, selection.Count):
            selected.append(AnyObject(selection.Item(i + 1).Value))

        return selected

    def spa_workbench(self):
        """

        Returns:

        """

        return SPAWorkbench(self.com_object)

    def __repr__(self):
        return f'Document(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-18 10:56:40.651039

from .factory import Factory


class InstanceFactory(Factory):
    """
        .. note::
            CAA V5 Visual Basic help

                | Represents the CATIAInstanceFactory.Role: This interface is used to
                | create a new instance of a shape reference
                | (activateLinkAnchor('ShapeInstance','','ShapeInstance')) or a hybrid
                | shape reference
                | (activateLinkAnchor('HybridShapeInstance','','HybridShapeInstance'))
                | in case of the instantiation of aUser Feature.It is also used to
                | instantiate aPower Copyreference.This interface contains two protocols
                | of instantiation:

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.instance_factory = com_object

    def instantiation_mode(self, i_instantiation_mode_bstr):
        """
        .. note::
            CAA V5 Visual Basic help

                | InstantiationMode
                | o Property InstantiationMode(iInstantiationModeBSTR) (Write Only)
                | 
                | Sets the mode of instantiation to "Inside" or "After". Role:
                | This method should be called BEFORE the method
                | BeginInstantiate to take into account the desired
                | instantiation mode. It is used to set the destination path
                | of insertion of the template reference. Example: The
                | following example shows how to determine the instantiation
                | mode (Mode's value is "Inside" or "After"):
                | InstanceFactory.InstantationMode = Mode
                |

        :param i_instantiation_mode_bstr:
        :return:
        """
        self.instance_factory.InstantiationMode = i_instantiation_mode_bstr

    def add_instance(self, i_reference):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddInstance
                | o Func AddInstance(iReference) As
                | 
                | Creates a new instance of a shape or hybrid shape.
                |
                | Parameters:
                | iReference
                |    The reference shape or hybrid shape.
                |
                | Examples:
                | This example creates the instance NewInstance in the part.
                | Set NewInstance = instanceFactory.AddInstance(reference)

        :param i_reference:
        :return:
        """
        return self.instance_factory.AddInstance(i_reference)

    def begin_instance_factory(self, i_name_of_reference, i_name_of_document):
        """
        .. note::
            CAA V5 Visual Basic help

                | BeginInstanceFactory
                | o Sub BeginInstanceFactory(iNameOfReference,
                |                                    iNameOfDocument)
                | 
                | Initializes the instantiation process with the document
                | containing the reference. Role: Use this method to start
                | instantiating a reference in the current document. In that
                | method, the document containing the reference is locked in
                | session. It will be unlocked in the last step .
                |
                | Parameters:
                | iNameOfReference
                | 	The name of the reference to be instantiated.
                |  
                |  iDocumentFileName
                |   The name of the file containing the document where to find the reference to be instantiated.
                |
                | Examples:
                | The following example initializes the factory with a
                | document and a reference: InstanceFactory.BeginInstanceFacto
                | ry"NameOfReference","c:/tmp/NameOfDocument.CATPart"

        :param i_name_of_reference:
        :param i_name_of_document:
        :return:
        """
        return self.instance_factory.BeginInstanceFactory(i_name_of_reference, i_name_of_document)

    def begin_instantiate(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | BeginInstantiate
                | o Sub BeginInstantiate()
                | 
                | Initializes the data of the reference. Role: This is the
                | first method of the second step of instantiation. It is used
                | to initialize all data of the reference in the factory.
                | Example: The following example shows how to initialize the
                | factory: InstanceFactory.BeginInstantiate
                |
                | Parameters:

        :return:
        """
        return self.instance_factory.BeginInstantiate()

    def end_instance_factory(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | EndInstanceFactory
                | o Sub EndInstanceFactory()
                | 
                | Ends the instantiation process. Role: Use this method to end
                | the instantiation process. In that method the document
                | containing the reference is unlocked and released from the
                | session. Example: The following example shows how to end the
                | instantiation: InstanceFactory.EndInstanceFactory
                |
                | Parameters:
                |

        :return:
        """
        return self.instance_factory.EndInstanceFactory()

    def end_instantiate(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | EndInstantiate
                | o Sub EndInstantiate()
                | 
                | Ends the instantiation of the reference. Role: This is the
                | fifth and last method of the second step of instantiation.
                | It is used to end the instantiation: after this step, all
                | the links to the reference are broken. Example: The
                | following example shows how to end the instantiation:
                | InstanceFactory.EndInstantiate
                |
                | Parameters:
                |

        :return:
        """
        return self.instance_factory.EndInstantiate()

    def get_parameter(self, i_name):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetParameter
                | o Func GetParameter(iName) As
                | 
                | Retrieves a parameter of the reference by its name. Role:
                | This is the third method of the second step of
                | instantiation. This step is optional. It is used to retrieve
                | a parameter of the reference in order to change its value,
                | using the ValuateFromString method of the Parameter
                | interface. It has to be called on each parameter whose value
                | has to be changed.
                |
                | Parameters:
                | iName
                |    The name of the parameter.
                |
                | Examples:
                | The following example retrieves a parameter on the
                | reference: Set parameter =
                | InstanceFactory.GetParameter("Parameter1")

        :param i_name:
        :return:
        """
        return self.instance_factory.GetParameter(i_name)

    def instantiate(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Instantiate
                | o Func Instantiate() As
                | 
                | Instantiates the reference in the current document. Role:
                | This is the fourth method of the second step of
                | instantiation. It is used to duplicate or instantiate the
                | data of the reference. In case of Power Copy instantiation,
                | the data are duplicated and there is no created instance. In
                | case of User Feature instantiation, the data are
                | instantiated and an instance is created and returned.
                | Example: The following example instantiates the reference:
                | Set Instance = InstanceFactory.Instantiate
                |
                | Parameters:
                |

        :return:
        """
        return self.instance_factory.Instantiate()

    def put_input_data(self, i_name, i_input):
        """
        .. note::
            CAA V5 Visual Basic help

                | PutInputData
                | o Sub PutInputData(iName,
                |                            iInput)
                | 
                | Sets a value to an input of the reference. Role: This is the
                | second method of the second step of instantiation. It is
                | used to set a value to any input of the reference. It has to
                | be called on each input of the reference.
                |
                | Parameters:
                | iName
                |    The name of the input.
                |  
                |  iInput
                |    The element to set as the new value of the input.
                |    All types of 
                | 
                |  object are possibly supported.
                |
                | Examples:
                | The following example sets a value to an input of the
                | reference: The input is a point and its name is Input1.
                | InstanceFactory.PutInputData "Input1",point1

        :param i_name:
        :param i_input:
        :return:
        """
        return self.instance_factory.PutInputData(i_name, i_input)

    def __repr__(self):
        return f'InstanceFactory(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.any_object import AnyObject


class Reference(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | Represents an object pointing to another object.This other object can
                | be either a wireframeactivateLinkAnchor('GeometricElement','','Geometr
                | icElement')object such as a plane or a line, or a boundary
                | representation object such as a face, a vertex or an edge. It may be,
                | in particular, aactivateLinkAnchor('Boundary','','Boundary')object.
                | References are created using appropriate methods for parts. They are
                | then passed to an object to enable associativity with the referenced
                | object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.reference = com_object

    @property
    def display_name(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | DisplayName
                | o Property DisplayName() As CATBSTR
                | 
                | Returns the name of the referenced object. The name of the referenced
                | object is either the name displayed in the specification tree for a
                | activateLinkAnchor('GeometricElement','','GeometricElement')  object
                | or a character string defining the reference for a boundary object.
                | Example:The following example returns in StrName the displayable name
                | of reference FirstRef:  StrName = FirstRef.DisplayName

        """
        return self.reference.DisplayName

    def compose_with(self, i_reference):
        """
        .. note::
            CAA V5 Visual Basic help

                | ComposeWith
                | o Func ComposeWith(    Reference    iReference) As Reference
                | 
                | Composes a reference with another reference thus creating a new
                | composite reference.


                | Parameters:
                | iReference
                |    The reference to be composed with the current reference.


                | Examples:
                | 
                | The following example returns in CompositeRef
                | the reference resulting
                | from the composition of the FirstRef
                | and SecondRef references.
                | 
                | Dim CompositeRef As Reference
                | Set CompositeRef = FirstRef.ComposeWith(SecondRef)

        """
        return Reference(self.reference.ComposeWith(i_reference))

    def __repr__(self):
        return f'Reference(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-18 10:56:40.651039

from pycatia.system_interfaces.collection import Collection
from .fix_together import FixTogether


class FixTogethers(Collection):
    """
        .. note::
            CAA V5 Visual Basic help

                | A collection of all the FixTogether objects contained in the product.

    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=FixTogether)
        self.fix_togethers = com_object

    def add(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Add
                | o Func Add() As
                | 
                | Creates a new FixTogether and adds it to the FixTogethers
                | collection. Returns: The created FixTogether
                |
                | Example:
                | The following example creates a FixTogether newFixTogether in
                | the FixTogether collection.
                | Set newFixTogether = fixTogethers.Add

        :return: FixTogether()
        """
        return self.child_object(self.fix_togethers.Add())

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(iIndex) As
                | 
                | Returns a FixTogether using its index or its name from the
                | FixTogethers collection.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the FixTogether to retrieve from
                |    the collection of FixTogether.
                |    As a numerics, this index is the rank of the FixTogether
                |    in the collection.
                |    The index of the first FixTogether in the collection is 1, and
                |    the index of the last FixTogether is Count.
                |    As a string, it is the name you assigned to the FixTogether using
                |    the property.
                | Returns:
                |    The retrieved FixTogether
                |
                | Examples:
                | This example retrieves in thisFixTogether the fifth
                | FixTogether in the collection and in thatFixTogether the
                | FixTogether named MyFixTogether in the FixTogether
                | collection of the product product.
                | Set fixTogetherColl = product.FixTogethers
                | Set thisFixTogether = fixTogetherColl.Item(5)
                | Set thatFixTogether = fixTogetherColl.Item("MyFixTogether")

        :param int i_index:
        :return: FixTogether()
        """
        return self.child_object(self.fix_togethers.Item(i_index))

    def remove(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Remove
                | o Sub Remove(iIndex)
                | 
                | Removes a FixTogether from the FixTogethers collection.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the FixTogether to remove from the FixTogethers
                |    collection.
                |    As a numerics, this index is the rank of the FixTogether
                |    in the collection.
                |    The index of the first FixTogether in the collection is 1, and
                |    the index of the last FixTogether is Count.
                |    As a string, it is the name you assigned to the FixTogether using
                |    the property.
                |
                | Examples:
                | This example removes the last FixTogether in the collection.
                | fixTogetherColl.Remove(fixTogetherColl.Count)

        :param int i_index:
        :return:
        """

        self.fix_togethers.Remove(i_index)

    def __repr__(self):
        return f'FixTogethers(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25

from pycatia.system_interfaces.collection import Collection
from .boundary import Boundary
from .shape import Shape


class Shapes(Collection):
    """
        .. note::
            CAA V5 Visual Basic help

                | The collection of the shapes making up a body.

    """

    def __init__(self, collection_com_object):
        super().__init__(collection_com_object, child_object=Shape)
        self.shapes = collection_com_object

    def get_boundary(self, i_label):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetBoundary
                | o Func GetBoundary(iLabel) As Boundary
                | 
                | Returns a boundary using its label.
                |
                | Parameters:
                | iLabel
                |    Identification of the Boundary object. See Reference.DisplayName.
                | . 
                |    Returns:
                |   The retrieved boundary

        :return: Boundary()
        """
        return Boundary(self.shapes.GetBoundary(i_label))

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(iIndex) As
                | 
                | Returns a shape using its index or its name from the Shapes
                | collection.


                | Parameters:
                | iIndex
                |    The index or the name of the shape to retrieve from
                |    the collection of shapes.
                |    As a numeric, this index is the rank of the shape
                |    in the collection.
                |    The index of the first shape in the collection is 1, and
                |    the index of the last shape is 
                | 
                | .   As a string, it is the name you assigned to the shape using
                |    the 
                |  property. 
                |    Returns:
                |   The retrieved shape
                |
                | Examples:
                | 
                | This example retrieves in ThisShape the third shape,
                | and in ThatShape the shape named
                | MyShape in the shape collection of the active document,
                | supposed to be a part document.
                | 
                | Set ThisShape = CATIA.ActiveDocument.Shapes.Item(3)
                | Set ThatShape = CATIA.ActiveDocument.Shapes.Item("MyShape")

        :return: Shape
        """
        return self.child_object(self.shapes.Item(i_index))

    def __repr__(self):
        return f'Shapes(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.system_service import SystemService


class Analyze(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | Represents the analysis object associated with a product.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analyze = com_object

    @property
    def mass(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Mass
                | o Property Mass() As double
                |
                | Returns the product mass value.  Example:    This example retrieves
                | MassValue from   the Analyze object associated with myProduct:
                | MassValue = myProduct.Analyze.Mass

        :return: float
        """
        return self.analyze.Mass

    @property
    def volume(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Volume
                | o Property Volume() As double
                |
                | Returns the product volume value.  Example:    This example retrieves
                | VolumeValue from   the Analyze object associated with myProduct:
                | VolumeValue = myProduct.Analyze.Volume


                | Parameters:


        """
        return self.analyze.Volume

    @property
    def wet_area(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | WetArea
                | o Property WetArea() As double
                |
                | Returns the product wet area (outer volume). Note: This method uses
                | mm2 instead of default Catia V5 unit.  Example:    This example
                | retrieves WetAreaValue from   the Analyze object associated with
                | myProduct:  WetAreaValue = myProduct.Analyze.WetArea


                | Parameters:


        """
        return self.analyze.WetArea

    def get_gravity_center(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetGravityCenter
                | o Sub GetGravityCenter(    CATSafeArrayVariant    oGravityCenterCoordinatesArray)
                |
                | Returns the gravity center coordinates of product.
                |
                | Parameters:
                | Coordinates
                |    The array storing the three gravity center coordinates.
                |    This array must be previously initialized.
                |
                | Examples:
                | This example retrieves the gravity center coordinates in
                | oGravityCenterCoordinatesArray from
                | the Analyze object associated with myProduct:
                |
                | ' Coordinates array initialization
                | Dim oGravityCenterCoordinatesArray ( 2 )
                | ' Get value in array
                | Myproduct.Analyze.GetGravityCenter oGravityCenterCoordinatesArray
        """

        vba_function_name = 'get_gravity_center'
        vba_function = 'GetGravityCenter'
        vba_code = f'''        
        Public Function {vba_function_name}(analyze)
            Dim coord(2)
            analyze.{vba_function} coord
            {vba_function_name} = coord
        End Function
        '''
        system_service = SystemService(self.application.SystemService)
        result = system_service.evaluate(vba_code, 0, vba_function_name, [self.analyze])

        return result

    def get_inertia(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInertia
                | o Sub GetInertia(    CATSafeArrayVariant    oInertiaMatrixArray)
                |
                | Returns the inertia matrix array of product.


                | Parameters:
                | oInertiaMatrixArray
                |    The array storing successively the three columns of inertia matrix.
                |    This array must be previously initialized.


                | Examples:
                |
                | This example retrieves the inertia matrix components in
                | oInertiaMatrixArray from
                | the Analyze object associated with myProduct:
                |
                | ' Components array initialization
                | Dim oInertiaMatrixArray ( 8 )
                | ' Get value in array
                | Myproduct.Analyze.GetInertia oInertiaMatrixArray
                | ' oInertiaMatrixArray ( 0 ) is the Ixx component
                | ' oInertiaMatrixArray ( 1 ) is the Ixy component
                | ' oInertiaMatrixArray ( 2 ) is the Ixz component
                | ' oInertiaMatrixArray ( 3 ) is the Iyx component
                | ' oInertiaMatrixArray ( 4 ) is the Iyy component
                | ' oInertiaMatrixArray ( 5 ) is the Iyz component
                | ' oInertiaMatrixArray ( 6 ) is the Izx component
                | ' oInertiaMatrixArray ( 7 ) is the Izy component
                | ' oInertiaMatrixArray ( 8 ) is the Izz component
                |
                |
                |
        """
        vba_function_name = 'get_inertia'
        vba_function = 'GetInertia'
        vba_code = f'''        
        Public Function {vba_function_name}(analyze)
            Dim coord(8)
            analyze.{vba_function} coord
            {vba_function_name} = coord
        End Function
        '''
        system_service = SystemService(self.application.SystemService)
        result = system_service.evaluate(vba_code, 0, vba_function_name, [self.analyze])

        return result

    def __repr__(self):
        return f'Analyze()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.any_object import AnyObject
from .geometric_elements import GeometricElements
from .hybrid_shapes import HybridShapes
from .sketches import Sketches


class HybridBody(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | The object is a hybrid body.The hybrid body manages a set of geometric
                | elements, a set of hybrid shapes, a set of bodies and a set of hybrid
                | bodies.It belongs to
                | theactivateLinkAnchor('HybridBodies','','HybridBodies')collection of
                | aactivateLinkAnchor('Part','','Part')or @ref CATIABody
                | oractivateLinkAnchor('HybridBody','','HybridBody')object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_body = com_object
        self.com_object = com_object

    @property
    def bodies(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Bodies
                | o Property Bodies() As Bodies
                | 
                | Returns the hybrid body's Bodies collection.  Example:The following
                | example returns in bodyColl the collection of bodies of the hybrid
                | body hybridBody :  Set bodyColl = hybridBody.Bodies

        :return: Body()
        """
        from pycatia.mec_mod_interfaces.bodies import Bodies
        return Bodies(self.hybrid_body.Bodies)

    @property
    def geometric_elements(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | GeometricElements
                | o Property GeometricElements() As GeometricElements
                | 
                | Returns the list of geometrical elements included in the hybrid body.
                | Returns:  oGeometricElements   The list of geometric elements in the
                | hybrid body (@see CATIAGeometricElements   for more information).
                |
                | Example:
                | The following example returns in geometricElements the list of
                | geometrical elements in the Hybrid body hybridBody:
                | Dim geometricElements As GeometricElements
                | Set geometricElements = hybridBody.GeometricElements

        :return: GeometricElements()
        """
        return GeometricElements(self.hybrid_body.GeometricElements)

    @property
    def hybrid_bodies(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | HybridBodies
                | o Property HybridBodies() As HybridBodies
                | 
                | Returns the hybrid body's HybridBodies collection.
                |
                | Example:
                | The following example returns in hybridBodyColl the collection of hybrid
                | bodies of the hybrid body hybridBody :
                | Set hybridBodyColl = hybridBody.HybridBodies

        :return: HybridBodies()
        """
        from pycatia.mec_mod_interfaces.hybrid_bodies import HybridBodies
        return HybridBodies(self.hybrid_body.HybridBodies)

    @property
    def hybrid_shapes(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | HybridShapes
                | o Property HybridShapes() As HybridShapes
                | 
                | Returns the list of hybrid shapes included in the hybrid body.
                | Returns:  oHybridShapes   The list of hybrid shapes in the hybrid body
                | (@see CATIAHybridShapes   for more information).
                |
                | Example:
                | The following example returns in hybridShapes the list of hybrid shapes in the
                | hybrid body hybridBody:
                | Dim hybridShapes As HybridShapes
                | Set hybridShapes = hybridBody.HybridShapes

        :return: HybridShapes()
        """
        return HybridShapes(self.hybrid_body.HybridShapes)

    @property
    def hybrid_sketches(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | HybridSketches
                | o Property HybridSketches() As Sketches
                | 
                | Returns the hybrid body's Sketches collection. These sketches are
                | those inside the hybrid body at all levels.  Example:The following
                | example returns in skColl the collection of sketches of a hybrid body
                | :  Set skColl = hybridBody.HybridSketches

        :return: Sketches()
        """
        return Sketches(self.hybrid_body.HybridSketches)

    def append_hybrid_shape(self, i_hybrid_shape):
        """
        .. note::
            CAA V5 Visual Basic help

                | AppendHybridShape
                | o Sub AppendHybridShape(    HybridShape    iHybridShape)
                | 
                | Appends a hybrid shape to the hybrid body.
                |
                | Parameters:
                | iHybriShape
                |   The hybrid shape to append.
                |
                | Examples:
                |
                | This example appends the hybrid shape hybridShape
                | to the hybrid body hybridBody:
                | 
                | hybridBody.AppendHybridShape (hybridShape)
        """
        self.hybrid_body.AppendHybridShape(i_hybrid_shape.com_object)

    def __repr__(self):
        return f'HybridBody(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-18 10:56:40.651039


from .edge import Edge


class BiDimFeatEdge(Edge):
    """
        .. note::
            CAA V5 Visual Basic help

                | 1-D boundary belonging to a feature whose topological result is two
                | dimensional.Role:
                | ThisactivateLinkAnchor('Boundary','','Boundary')object may be, for
                | example, the edge of a surface obtained through the extrusion of a
                | spline.  You will create a BiDimFeatEdge object using theactivateLinkA
                | nchor('Shapes','GetBoundary','Shapes.GetBoundary'),activateLinkAnchor(
                | 'HybridShapes','GetBoundary','HybridShapes.GetBoundary'),activateLinkA
                | nchor('Sketches','GetBoundary','Sketches.GetBoundary')oractivateLinkAn
                | chor('Selection','SelectElement2','Selection.SelectElement2')method.
                | Then, you pass it to the operator (such asactivateLinkAnchor('HybridSh
                | apeFactory','AddNewPointOnCurveFromDistance','HybridShapeFactory.AddNe
                | wPointOnCurveFromDistance')).  The lifetime of a BiDimFeatEdge object
                | is limited, seeactivateLinkAnchor('Boundary','','Boundary').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.bi_dim_feat_edge = com_object

    def __repr__(self):
        return f'BiDimFeatEdge(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25

from pycatia.system_interfaces.any_object import AnyObject


class Factory(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | Abstract object gathering behaviours of all objects being a factory.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.factory = com_object

    def __repr__(self):
        return f'Factory()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25

from pycatia.system_interfaces.any_object import AnyObject
from .hybrid_shapes import HybridShapes
from .sketches import Sketches


class OrderedGeometricalSet(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | The object is an ordered geometrical set.The ordered geometrical set
                | manages a set of hybrid shapes, a set of bodies and a set of ordered
                | geometrical sets.It belongs to theactivateLinkAnchor('OrderedGeometric
                | alSets','','OrderedGeometricalSets')collection of aactivateLinkAnchor(
                | 'Part','','Part')oractivateLinkAnchor('OrderedGeometricalSet','','Orde
                | redGeometricalSet')object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ordered_geometrical_set = com_object

    @property
    def bodies(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Bodies
                | o Property Bodies() As   (Read Only)
                | 
                | Returns the ordered geometrical set's Bodies collection.
                |
                | Example:
                | The following example returns in bodyColl the collection of bodies of the
                | ordered geometrical set OrderedGeometricalSet1 :
                | Set bodyColl = OrderedGeometricalSet1.Bodies

        :return: Bodies()
        """
        from pycatia.mec_mod_interfaces.bodies import Bodies
        return Bodies(self.ordered_geometrical_set.Bodies)

    @property
    def hybrid_shapes(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | HybridShapes
                | o Property HybridShapes() As   (Read Only)
                | 
                | Returns the list of hybrid shapes included in the ordered geometrical
                | set.  Returns:  oHybridShapes   The list of hybrid shapes in the
                | ordered geometrical set (@see CATIAHybridShapes   for more
                | information).
                |
                | Example:
                | The following example returns in HybridShapes1
                | the list of   hybrid shapes in the ordered geometrical
                | setOrderedGeometricalSet1:
                | Dim HybridShapes1 As HybridShapes
                | Set HybridShapes1 = OrderedGeometricalSet1.HybridShapes

        :return: HybridShapes
        """
        return HybridShapes(self.ordered_geometrical_set.HybridShapes)

    @property
    def ordered_geometrical_sets(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | OrderedGeometricalSets
                | o Property OrderedGeometricalSets() As   (Read Only)
                | 
                | Returns the ordered geometrical set's OrderedGeometricalSets
                | collection.
                | Example:
                | The following example returns in
                | OrderedGeometricalSetColl the collection of  ordered geometrical set
                | of the ordered geometrical set OrderedGeometricalSet1 :
                | Set OrderedGeometricalSetColl = OrderedGeometricalSet1.OrderedGeometricalSets

        :return: OrderedGeometricalSets()
        """
        from pycatia.mec_mod_interfaces.ordered_geometrical_sets import OrderedGeometricalSets
        return OrderedGeometricalSets(self.ordered_geometrical_set.OrderedGeometricalSets)

    @property
    def ordered_sketches(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | OrderedSketches
                | o Property OrderedSketches() As   (Read Only)
                | 
                | Returns the ordered geometrical set's Sketches collection. These
                | sketches are those inside the ordered geometrical set at all levels.
                |
                | Example:
                | The following example returns in sketchesCollection the
                | collection of sketches of an ordered geometrical set :
                | Set sketchesCollection = OrderedGeometricalSet1.OrderedSketches

        """
        return Sketches(self.ordered_geometrical_set.OrderedSketches)

    def insert_hybrid_shape(self, i_hybrid_shape):
        """
        .. note::
            CAA V5 Visual Basic help

                | InsertHybridShape
                | o Sub InsertHybridShape(iHybridShape)
                | 
                | Inserts a hybrid shape to the ordered geometrical set.
                |
                | Parameters:
                | iHybridShape
                |   The hybrid shape to insert.
                |
                | Examples:
                | This example inserts the hybrid shape HybridShape1
                | to the ordered geometrical set OrderedGeometricalSet1:
                | OrderedGeometricalSet1.InsertHybridShape (HybridShape1)

        """
        self.ordered_geometrical_set.InsertHybridShape(i_hybrid_shape)

    def __repr__(self):
        return f'OrderedGeometricalSet()'
